@@ -50,7 +50,14 @@ class Cluster(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Cluster.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["ClusterProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -100,7 +107,16 @@ class ClusterProps:
         :param v_switch_id: Property vSwitchId: VSwitch id.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ClusterProps.__init__)
+            def stub(
+                *,
+                cluster_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                vpc_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                policy: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosCluster.PolicyProperty", typing.Dict[str, typing.Any]]]] = None,
+                v_switch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cluster_type", value=cluster_type, expected_type=type_hints["cluster_type"])
             check_type(argname="argument vpc_id", value=vpc_id, expected_type=type_hints["vpc_id"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
@@ -193,7 +209,14 @@ class Instance(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Instance.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["InstanceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -300,7 +323,27 @@ class InstanceProps:
         :param v_switch_id: Property vSwitchId: VSwitch id.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceProps.__init__)
+            def stub(
+                *,
+                cluster_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                image_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                system_disk_category: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                system_disk_size: typing.Union[jsii.Number, ros_cdk_core.IResolvable],
+                work_mode: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                allocate_public_address: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                app_list: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.AppListProperty", typing.Dict[str, typing.Any]]]]]] = None,
+                auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                instance_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                internet_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                internet_max_bandwidth_out: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                period_unit: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                v_switch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
             check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
@@ -521,7 +564,14 @@ class RosCluster(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosCluster.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosClusterProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -537,7 +587,9 @@ class RosCluster(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosCluster._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -585,7 +637,11 @@ class RosCluster(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "cluster_type").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clusterType", value)
 
@@ -597,7 +653,9 @@ class RosCluster(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -615,7 +673,11 @@ class RosCluster(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "vpc_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vpcId", value)
 
@@ -635,7 +697,11 @@ class RosCluster(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "name").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -655,7 +721,11 @@ class RosCluster(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosCluster.PolicyProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "policy").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosCluster.PolicyProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "policy", value)
 
@@ -675,7 +745,11 @@ class RosCluster(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosCluster, "v_switch_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vSwitchId", value)
 
@@ -705,7 +779,15 @@ class RosCluster(
             :param watermark: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosCluster.PolicyProperty.__init__)
+                def stub(
+                    *,
+                    clipboard: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    local_drive: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    usb_redirect: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    watermark: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument clipboard", value=clipboard, expected_type=type_hints["clipboard"])
                 check_type(argname="argument local_drive", value=local_drive, expected_type=type_hints["local_drive"])
                 check_type(argname="argument usb_redirect", value=usb_redirect, expected_type=type_hints["usb_redirect"])
@@ -795,7 +877,16 @@ class RosClusterProps:
         :param v_switch_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosClusterProps.__init__)
+            def stub(
+                *,
+                cluster_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                vpc_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                policy: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosCluster.PolicyProperty, typing.Dict[str, typing.Any]]]] = None,
+                v_switch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cluster_type", value=cluster_type, expected_type=type_hints["cluster_type"])
             check_type(argname="argument vpc_id", value=vpc_id, expected_type=type_hints["vpc_id"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
@@ -897,7 +988,14 @@ class RosInstance(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstance.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosInstanceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -913,7 +1011,9 @@ class RosInstance(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstance._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -990,7 +1090,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "cluster_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clusterId", value)
 
@@ -1002,7 +1106,9 @@ class RosInstance(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1020,7 +1126,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "image_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
@@ -1038,7 +1148,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "instance_type").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
@@ -1058,7 +1172,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "system_disk_category").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "systemDiskCategory", value)
 
@@ -1076,7 +1194,11 @@ class RosInstance(
         value: typing.Union[jsii.Number, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "system_disk_size").fset)
+            def stub(
+                value: typing.Union[jsii.Number, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "systemDiskSize", value)
 
@@ -1098,7 +1220,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "work_mode").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "workMode", value)
 
@@ -1118,7 +1244,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "allocate_public_address").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allocatePublicAddress", value)
 
@@ -1138,7 +1268,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[ros_cdk_core.IResolvable, "RosInstance.AppListProperty"]]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "app_list").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[ros_cdk_core.IResolvable, "RosInstance.AppListProperty"]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "appList", value)
 
@@ -1158,7 +1292,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "auto_renew").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "autoRenew", value)
 
@@ -1182,7 +1320,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "instance_charge_type").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceChargeType", value)
 
@@ -1207,7 +1349,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "internet_charge_type").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internetChargeType", value)
 
@@ -1232,7 +1378,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "internet_max_bandwidth_out").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internetMaxBandwidthOut", value)
 
@@ -1252,7 +1402,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "name").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -1277,7 +1431,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "period").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "period", value)
 
@@ -1300,7 +1458,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "period_unit").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "periodUnit", value)
 
@@ -1320,7 +1482,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "v_switch_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vSwitchId", value)
 
@@ -1347,7 +1513,14 @@ class RosInstance(
             :param app_path: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosInstance.AppListProperty.__init__)
+                def stub(
+                    *,
+                    app_args: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                    app_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                    app_path: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument app_args", value=app_args, expected_type=type_hints["app_args"])
                 check_type(argname="argument app_name", value=app_name, expected_type=type_hints["app_name"])
                 check_type(argname="argument app_path", value=app_path, expected_type=type_hints["app_path"])
@@ -1464,7 +1637,27 @@ class RosInstanceProps:
         :param v_switch_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstanceProps.__init__)
+            def stub(
+                *,
+                cluster_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                image_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                system_disk_category: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                system_disk_size: typing.Union[jsii.Number, ros_cdk_core.IResolvable],
+                work_mode: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                allocate_public_address: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                app_list: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.AppListProperty, typing.Dict[str, typing.Any]]]]]] = None,
+                auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                instance_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                internet_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                internet_max_bandwidth_out: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                period_unit: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                v_switch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
             check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
